==> PyMandel-1.0.0.tar.gz: PyMandel-1.0.0/colormaps/pastels256_colormap.py <==
from numpy import array

'''
Colormap created by make_colormap utility from file pastels256.png
'''
pastels256 = array([ \
[245, 220, 183],
[244, 218, 187],
[245, 216, 191],
[245, 214, 193],
[245, 212, 197],
[245, 210, 200],
[246, 209, 204],
[245, 206, 207],
[246, 206, 209],
[245, 205, 211],
[245, 203, 213],
[246, 202, 215],
[246, 201, 217],
[245, 199, 219],
[245, 198, 221],
[246, 197, 223],
[245, 196, 226],
[246, 195, 228],
[245, 193, 231],
[245, 192, 233],
[245, 191, 235],
[245, 190, 237],
[244, 190, 237],
[241, 191, 238],
[238, 192, 238],
[236, 192, 240],
[233, 194, 239],
[230, 194, 240],
[227, 195, 241],
[224, 197, 241],
[222, 198, 241],
[217, 199, 243],
[208, 202, 243],
[198, 206, 246],
[194, 206, 243],
[193, 203, 239],
[193, 200, 235],
[192, 198, 231],
[191, 195, 226],
[191, 193, 222],
[190, 189, 217],
[190, 187, 213],
[189, 184, 208],
[188, 180, 200],
[187, 175, 192],
[185, 169, 183],
[185, 164, 174],
[184, 161, 170],
[183, 162, 174],
[182, 163, 179],
[181, 165, 183],
[181, 167, 188],
[180, 168, 191],
[179, 169, 196],
[178, 171, 201],
[178, 172, 205],
[177, 174, 210],
[176, 176, 216],
[175, 177, 221],
[174, 178, 226],
[174, 181, 231],
[173, 183, 237],
[172, 185, 242],
[171, 186, 248],
[174, 189, 246],
[176, 191, 246],
[179, 193, 245],
[183, 196, 244],
[185, 199, 243],
[188, 201, 242],
[191, 203, 240],
[194, 206, 240],
[197, 209, 239],
[199, 211, 238],
[203, 214, 236],
[206, 216, 236],
[212, 221, 234],
[217, 226, 232],
[224, 231, 230],
[229, 237, 228],
[235, 242, 226],
[241, 247, 224],
[243, 246, 222],
[243, 242, 220],
[243, 237, 218],
[244, 233, 216],
[244, 230, 215],
[244, 226, 213],
[244, 222, 211],
[245, 217, 210],
[246, 213, 208],
[245, 210, 206],
[246, 206, 203],
[247, 198, 200],
[247, 190, 197],
[247, 183, 193],
[248, 174, 189],
[249, 166, 186],
[246, 161, 182],
[240, 159, 180],
[233, 157, 177],
[227, 155, 174],
[221, 153, 172],
[213, 151, 169],
[208, 148, 167],
[201, 147, 163],
[194, 145, 162],
[188, 143, 159],
[181, 140, 156],
[175, 139, 153],
[167, 136, 151],
[160, 134, 148],
[153, 132, 145],
[145, 129, 141],
[139, 126, 138],
[131, 125, 136],
[124, 122, 133],
[116, 120, 130],
[109, 118, 127],
[102, 116, 125],
[102, 116, 125],
[106, 118, 127],
[109, 120, 129],
[113, 122, 131],
[117, 125, 132],
[121, 127, 134],
[125, 130, 136],
[129, 131, 138],
[132, 134, 140],
[136, 137, 142],
[139, 139, 145],
[143, 141, 146],
[147, 143, 148],
[151, 145, 150],
[154, 148, 151],
[158, 150, 154],
[162, 152, 156],
[165, 154, 157],
[170, 157, 160],
[173, 159, 162],
[179, 162, 164],
[188, 168, 169],
[197, 173, 173],
[206, 179, 178],
[215, 184, 183],
[223, 190, 187],
[233, 194, 192],
[242, 200, 197],
[250, 205, 202],
[242, 196, 200],
[232, 188, 198],
[224, 179, 196],
[214, 170, 195],
[208, 165, 194],
[205, 161, 193],
[202, 159, 192],
[198, 155, 191],
[195, 152, 191],
[192, 149, 190],
[189, 146, 189],
[185, 141, 188],
[182, 138, 188],
[178, 135, 187],
[175, 132, 186],
[171, 129, 186],
[172, 129, 185],
[173, 132, 186],
[176, 134, 187],
[178, 137, 187],
[180, 139, 187],
[182, 141, 188],
[184, 144, 189],
[187, 146, 189],
[189, 149, 190],
[191, 151, 190],
[192, 153, 191],
[195, 156, 191],
[197, 159, 192],
[199, 161, 192],
[201, 163, 193],
[203, 166, 193],
[205, 169, 194],
[208, 171, 194],
[210, 173, 194],
[214, 178, 195],
[221, 186, 197],
[228, 194, 198],
[235, 202, 199],
[242, 210, 201],
[249, 218, 203],
[250, 219, 204],
[247, 212, 205],
[245, 206, 206],
[242, 199, 207],
[239, 193, 208],
[235, 187, 209],
[232, 180, 210],
[230, 174, 210],
[227, 168, 212],
[224, 162, 213],
[222, 155, 214],
[218, 149, 214],
[216, 143, 215],
[213, 137, 216],
[210, 132, 217],
[207, 125, 218],
[208, 127, 216],
[211, 134, 213],
[215, 142, 210],
[219, 150, 206],
[223, 158, 203],
[227, 165, 200],
[230, 172, 196],
[232, 179, 193],
[236, 185, 191],
[239, 191, 188],
[241, 197, 186],
[245, 204, 183],
[247, 209, 181],
[250, 216, 178],
[254, 222, 175],
[254, 223, 178],
[254, 224, 182],
[254, 225, 187],
[254, 226, 191],
[254, 227, 195],
[254, 228, 199],
[254, 229, 203],
[254, 230, 208],
[254, 231, 215],
[254, 232, 221],
[255, 234, 228],
[254, 235, 236],
[254, 237, 243],
[255, 235, 243],
[255, 234, 242],
[254, 232, 241],
[254, 230, 241],
[254, 228, 240],
[255, 227, 239],
[254, 225, 238],
[255, 223, 237],
[254, 221, 236],
[254, 220, 236],
[254, 219, 235],
[254, 217, 234],
[255, 214, 233],
[255, 213, 232],
[255, 210, 230],
[254, 208, 229],
[255, 205, 228],
[255, 202, 226],
[255, 200, 225],
[255, 198, 224],
[255, 195, 223],
[255, 192, 222]])
'''
End of colormap from pastels256.png
'''

==> PyMandel-1.0.7.tar.gz: PyMandel-1.0.7/colormaps/pastels256_colormap.py <==
from numpy import array

#****************************************************************************************
# 256-level colormap created by make_colormap utility from file pastels256.png
#****************************************************************************************
pastels256 = array([ \
[245, 220, 183],
[244, 218, 187],
[245, 216, 191],
[245, 214, 193],
[245, 212, 197],
[245, 210, 200],
[246, 209, 204],
[245, 206, 207],
[246, 206, 209],
[245, 205, 211],
[245, 203, 213],
[246, 202, 215],
[246, 201, 217],
[245, 199, 219],
[245, 198, 221],
[246, 197, 223],
[245, 196, 226],
[246, 195, 228],
[245, 193, 231],
[245, 192, 233],
[245, 191, 235],
[245, 190, 237],
[244, 190, 237],
[241, 191, 238],
[238, 192, 238],
[236, 192, 240],
[233, 194, 239],
[230, 194, 240],
[227, 195, 241],
[224, 197, 241],
[222, 198, 241],
[217, 199, 243],
[208, 202, 243],
[198, 206, 246],
[194, 206, 243],
[193, 203, 239],
[193, 200, 235],
[192, 198, 231],
[191, 195, 226],
[191, 193, 222],
[190, 189, 217],
[190, 187, 213],
[189, 184, 208],
[188, 180, 200],
[187, 175, 192],
[185, 169, 183],
[185, 164, 174],
[184, 161, 170],
[183, 162, 174],
[182, 163, 179],
[181, 165, 183],
[181, 167, 188],
[180, 168, 191],
[179, 169, 196],
[178, 171, 201],
[178, 172, 205],
[177, 174, 210],
[176, 176, 216],
[175, 177, 221],
[174, 178, 226],
[174, 181, 231],
[173, 183, 237],
[172, 185, 242],
[171, 186, 248],
[174, 189, 246],
[176, 191, 246],
[179, 193, 245],
[183, 196, 244],
[185, 199, 243],
[188, 201, 242],
[191, 203, 240],
[194, 206, 240],
[197, 209, 239],
[199, 211, 238],
[203, 214, 236],
[206, 216, 236],
[212, 221, 234],
[217, 226, 232],
[224, 231, 230],
[229, 237, 228],
[235, 242, 226],
[241, 247, 224],
[243, 246, 222],
[243, 242, 220],
[243, 237, 218],
[244, 233, 216],
[244, 230, 215],
[244, 226, 213],
[244, 222, 211],
[245, 217, 210],
[246, 213, 208],
[245, 210, 206],
[246, 206, 203],
[247, 198, 200],
[247, 190, 197],
[247, 183, 193],
[248, 174, 189],
[249, 166, 186],
[246, 161, 182],
[240, 159, 180],
[233, 157, 177],
[227, 155, 174],
[221, 153, 172],
[213, 151, 169],
[208, 148, 167],
[201, 147, 163],
[194, 145, 162],
[188, 143, 159],
[181, 140, 156],
[175, 139, 153],
[167, 136, 151],
[160, 134, 148],
[153, 132, 145],
[145, 129, 141],
[139, 126, 138],
[131, 125, 136],
[124, 122, 133],
[116, 120, 130],
[109, 118, 127],
[102, 116, 125],
[102, 116, 125],
[106, 118, 127],
[109, 120, 129],
[113, 122, 131],
[117, 125, 132],
[121, 127, 134],
[125, 130, 136],
[129, 131, 138],
[132, 134, 140],
[136, 137, 142],
[139, 139, 145],
[143, 141, 146],
[147, 143, 148],
[151, 145, 150],
[154, 148, 151],
[158, 150, 154],
[162, 152, 156],
[165, 154, 157],
[170, 157, 160],
[173, 159, 162],
[179, 162, 164],
[188, 168, 169],
[197, 173, 173],
[206, 179, 178],
[215, 184, 183],
[223, 190, 187],
[233, 194, 192],
[242, 200, 197],
[250, 205, 202],
[242, 196, 200],
[232, 188, 198],
[224, 179, 196],
[214, 170, 195],
[208, 165, 194],
[205, 161, 193],
[202, 159, 192],
[198, 155, 191],
[195, 152, 191],
[192, 149, 190],
[189, 146, 189],
[185, 141, 188],
[182, 138, 188],
[178, 135, 187],
[175, 132, 186],
[171, 129, 186],
[172, 129, 185],
[173, 132, 186],
[176, 134, 187],
[178, 137, 187],
[180, 139, 187],
[182, 141, 188],
[184, 144, 189],
[187, 146, 189],
[189, 149, 190],
[191, 151, 190],
[192, 153, 191],
[195, 156, 191],
[197, 159, 192],
[199, 161, 192],
[201, 163, 193],
[203, 166, 193],
[205, 169, 194],
[208, 171, 194],
[210, 173, 194],
[214, 178, 195],
[221, 186, 197],
[228, 194, 198],
[235, 202, 199],
[242, 210, 201],
[249, 218, 203],
[250, 219, 204],
[247, 212, 205],
[245, 206, 206],
[242, 199, 207],
[239, 193, 208],
[235, 187, 209],
[232, 180, 210],
[230, 174, 210],
[227, 168, 212],
[224, 162, 213],
[222, 155, 214],
[218, 149, 214],
[216, 143, 215],
[213, 137, 216],
[210, 132, 217],
[207, 125, 218],
[208, 127, 216],
[211, 134, 213],
[215, 142, 210],
[219, 150, 206],
[223, 158, 203],
[227, 165, 200],
[230, 172, 196],
[232, 179, 193],
[236, 185, 191],
[239, 191, 188],
[241, 197, 186],
[245, 204, 183],
[247, 209, 181],
[250, 216, 178],
[254, 222, 175],
[254, 223, 178],
[254, 224, 182],
[254, 225, 187],
[254, 226, 191],
[254, 227, 195],
[254, 228, 199],
[254, 229, 203],
[254, 230, 208],
[254, 231, 215],
[254, 232, 221],
[255, 234, 228],
[254, 235, 236],
[254, 237, 243],
[255, 235, 243],
[255, 234, 242],
[254, 232, 241],
[254, 230, 241],
[254, 228, 240],
[255, 227, 239],
[254, 225, 238],
[255, 223, 237],
[254, 221, 236],
[254, 220, 236],
[254, 219, 235],
[254, 217, 234],
[255, 214, 233],
[255, 213, 232],
[255, 210, 230],
[254, 208, 229],
[255, 205, 228],
[255, 202, 226],
[255, 200, 225],
[255, 198, 224],
[255, 195, 223],
[255, 192, 222]])
